@@ -1,7 +1,8 @@
-#options(par.unfoldr=1)
+\dontrun{
+#options(par.unfoldr=4)
 breaks <- setbreaks(c(8,6,7),maxSize=0.37,kap=1.25)
-
 breaks
 
 P <- coefficientMatrixSpheroids(breaks,check=FALSE)
 c(min(P),max(P),sum(P))
+}
